==> adams-core-0.3.1-sources.jar: adams/core/io/AbstractFilenameGenerator.java <==
/**
 * AbstractFilenameGenerator.java
 * Copyright (C) 2011 University of Waikato, Hamilton, New Zealand
 */
package adams.core.io;

import adams.core.option.OptionHandlingObject;

/**
 * Ancestor for filename generators.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 3966 $
 */
public abstract class AbstractFilenameGenerator
  extends OptionHandlingObject {

  /** for serialization. */
  private static final long serialVersionUID = -9019484464686478277L;

  /** the parent directory of the file. */
  protected PlaceholderDirectory m_Directory;

  /**
   * Adds options to the internal list of options.
   */
  public void defineOptions() {
    super.defineOptions();

    m_OptionManager.add(
	    "dir", "directory",
	    new PlaceholderDirectory("."));
  }

  /**
   * Sets the parent directory for the generated filename.
   *
   * @param value	the directory
   */
  public void setDirectory(PlaceholderDirectory value) {
    m_Directory = value;
    reset();
  }

  /**
   * Returns the parent directory for the generated filename.
   *
   * @return		the directory
   */
  public PlaceholderDirectory getDirectory() {
    return m_Directory;
  }

  /**
   * Returns the tip text for this property.
   *
   * @return 		tip text for this property suitable for
   * 			displaying in the GUI or for listing the options.
   */
  public String directoryTipText() {
    return "The parent directory of the generated filename.";
  }

  /**
   * Performs checks on the object to generate the filename for.
   * <p/>
   * Default implementation only checks whether object is null.
   *
   * @param obj		the object to check
   */
  protected void check(Object obj) {
    if (obj == null)
      throw new IllegalArgumentException("Object to generate filename for is null!");
  }

  /**
   * Performs the actual generation of the filename.
   *
   * @param obj		the object to generate the filename for
   * @return		the generated filename
   */
  protected abstract String doGenerate(Object obj);

  /**
   * Generates a filename for the object.
   *
   * @param obj		the object to generate the filename for
   * @return		the generated filename
   */
  public String generate(Object obj) {
    check(obj);
    return doGenerate(obj);
  }
}

==> adams-core-0.3.13-sources.jar: adams/core/io/AbstractFilenameGenerator.java <==
/**
 * AbstractFilenameGenerator.java
 * Copyright (C) 2011 University of Waikato, Hamilton, New Zealand
 */
package adams.core.io;

import adams.core.option.AbstractOptionHandler;

/**
 * Ancestor for filename generators.
 *
 * @author  fracpete (fracpete at waikato dot ac dot nz)
 * @version $Revision: 4397 $
 */
public abstract class AbstractFilenameGenerator
  extends AbstractOptionHandler {

  /** for serialization. */
  private static final long serialVersionUID = -9019484464686478277L;

  /** the parent directory of the file. */
  protected PlaceholderDirectory m_Directory;

  /**
   * Adds options to the internal list of options.
   */
  public void defineOptions() {
    super.defineOptions();

    m_OptionManager.add(
	    "dir", "directory",
	    new PlaceholderDirectory("."));
  }

  /**
   * Sets the parent directory for the generated filename.
   *
   * @param value	the directory
   */
  public void setDirectory(PlaceholderDirectory value) {
    m_Directory = value;
    reset();
  }

  /**
   * Returns the parent directory for the generated filename.
   *
   * @return		the directory
   */
  public PlaceholderDirectory getDirectory() {
    return m_Directory;
  }

  /**
   * Returns the tip text for this property.
   *
   * @return 		tip text for this property suitable for
   * 			displaying in the GUI or for listing the options.
   */
  public String directoryTipText() {
    return "The parent directory of the generated filename.";
  }

  /**
   * Performs checks on the object to generate the filename for.
   * <p/>
   * Default implementation only checks whether object is null.
   *
   * @param obj		the object to check
   */
  protected void check(Object obj) {
    if (obj == null)
      throw new IllegalArgumentException("Object to generate filename for is null!");
  }

  /**
   * Performs the actual generation of the filename.
   *
   * @param obj		the object to generate the filename for
   * @return		the generated filename
   */
  protected abstract String doGenerate(Object obj);

  /**
   * Generates a filename for the object.
   *
   * @param obj		the object to generate the filename for
   * @return		the generated filename
   */
  public String generate(Object obj) {
    check(obj);
    return doGenerate(obj);
  }
}
